@@ -41,8 +41,7 @@ OC.L10N.register(
     "Description of the page" : "Sivun kuvaus",
     "Save" : "Tallenna",
     "Previews" : "Esikatselut",
-    "Screenly API URL" : "Screenly-palvelun API:n URL",
-    "Screenly API key" : "Screenly-palvelun API-avain",
+    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Voit rekisteröityä ilmaiseksi osoitteessa <a href=\"http://screeenly.com\">screeenly.com</a> tai <a href=\"https://github.com/stefanzweifel/screeenly\">pystyttää oman palvelimen</a>.",
     "Bookmarks feed" : "Kirjanmerkkien syöte"
 },
 "nplurals=2; plural=(n != 1);");
