@@ -47,8 +47,6 @@ OC.L10N.register(
     "Previews" : "Anteprime",
     "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Per visualizzare le schermate effettive dei tuoi siti web preferiti, Segnalibri può utilizzare un servizio di terze parti per generarle.",
     "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Puoi registrarti gratuitamente su <a href=\"http://screeenly.com\">screeenly.com</a> o <a href=\"https://github.com/stefanzweifel/screeenly\">configurare il tuo server</a>.",
-    "Screenly API URL" : "URL API di Screenly",
-    "Screenly API key" : "Chiave API di Screenly",
     "Bookmarks feed" : "Fonte dei segnalibri"
 },
 "nplurals=2; plural=(n != 1);");
